==> resteasy-integration-tests-5.0.8.Final.zip: src/test/java/org/jboss/resteasy/test/providers/jaxb/resource/XmlJavaTypeAdapterAlienAdapter.java <==
package org.jboss.resteasy.test.providers.jaxb.resource;

import java.util.concurrent.atomic.AtomicInteger;

import javax.xml.bind.annotation.adapters.XmlAdapter;

import org.jboss.logging.Logger;

public class XmlJavaTypeAdapterAlienAdapter extends XmlAdapter<XmlJavaTypeAdapterHuman, XmlJavaTypeAdapterAlien> {
    public static AtomicInteger marshalCounter = new AtomicInteger(0);
    public static AtomicInteger unmarshalCounter = new AtomicInteger(0);
    private static Logger logger = Logger.getLogger(XmlJavaTypeAdapterResource.class.getName());

    public static void reset() {
        marshalCounter.set(0);
        unmarshalCounter.set(0);
        logger.info("reset()");
    }

    @Override
    public XmlJavaTypeAdapterHuman marshal(XmlJavaTypeAdapterAlien alien) throws Exception {
        logger.info("Entering AlienAdapter.marshal()");
        marshalCounter.incrementAndGet();
        XmlJavaTypeAdapterHuman human = new XmlJavaTypeAdapterHuman();
        human.setName(reverse(alien.getName()));
        return human;
    }

    @Override
    public XmlJavaTypeAdapterAlien unmarshal(XmlJavaTypeAdapterHuman human) throws Exception {
        logger.info("Entering AlienAdapter.unmarshal()");
        unmarshalCounter.incrementAndGet();
        XmlJavaTypeAdapterAlien alien = new XmlJavaTypeAdapterAlien();
        alien.setName(reverse(human.getName()));
        return alien;
    }

    protected static String reverse(String s) {
        return new StringBuilder(s).reverse().toString();
    }
}

==> resteasy-integration-tests-6.2.12.Final.zip: src/test/java/org/jboss/resteasy/test/providers/jaxb/resource/XmlJavaTypeAdapterAlienAdapter.java <==
package org.jboss.resteasy.test.providers.jaxb.resource;

import java.util.concurrent.atomic.AtomicInteger;

import jakarta.xml.bind.annotation.adapters.XmlAdapter;

import org.jboss.logging.Logger;

public class XmlJavaTypeAdapterAlienAdapter extends XmlAdapter<XmlJavaTypeAdapterHuman, XmlJavaTypeAdapterAlien> {
    public static AtomicInteger marshalCounter = new AtomicInteger(0);
    public static AtomicInteger unmarshalCounter = new AtomicInteger(0);
    private static Logger logger = Logger.getLogger(XmlJavaTypeAdapterResource.class.getName());

    public static void reset() {
        marshalCounter.set(0);
        unmarshalCounter.set(0);
        logger.info("reset()");
    }

    @Override
    public XmlJavaTypeAdapterHuman marshal(XmlJavaTypeAdapterAlien alien) throws Exception {
        logger.info("Entering AlienAdapter.marshal()");
        marshalCounter.incrementAndGet();
        XmlJavaTypeAdapterHuman human = new XmlJavaTypeAdapterHuman();
        human.setName(reverse(alien.getName()));
        return human;
    }

    @Override
    public XmlJavaTypeAdapterAlien unmarshal(XmlJavaTypeAdapterHuman human) throws Exception {
        logger.info("Entering AlienAdapter.unmarshal()");
        unmarshalCounter.incrementAndGet();
        XmlJavaTypeAdapterAlien alien = new XmlJavaTypeAdapterAlien();
        alien.setName(reverse(human.getName()));
        return alien;
    }

    protected static String reverse(String s) {
        return new StringBuilder(s).reverse().toString();
    }
}
